========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs| |binder|
    * - tests
      - | |CI| |PyPiPublished| |codecov| |codacy|
    * - package
      - | |version| |wheel| |supported-versions| |supported-implementations| |commits-since|
    * - Gitter
      - | General |gitter| Standard |std| Collusion |collusion| OneShot |oneshot|
.. |docs| image:: https://readthedocs.org/projects/anl/badge/?style=flat
    :target: https://anl.readthedocs.io/en/latest
    :alt: Documentation Status

.. |codecov| image:: https://codecov.io/gh/autoneg/anl/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/autoneg/anl
    :alt: Coverage Status

.. |codacy| image:: https://img.shields.io/codacy/grade/f9512287d5d0485a80cf39e75dfc6d22.svg
    :target: https://www.codacy.com/app/autoneg/anl
    :alt: Codacy Code Quality Status

.. |version| image:: https://img.shields.io/pypi/v/anl.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/anl

.. |wheel| image:: https://img.shields.io/pypi/wheel/anl.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/project/anl

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/anl.svg
    :alt: Supported versions
    :target: https://pypi.org/project/anl

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/anl.svg
    :alt: Supported implementations
    :target: https://pypi.org/project/anl

.. |commits-since| image:: https://img.shields.io/github/commits-since/autoneg/anl/v0.6.2.svg
    :alt: Commits since latest release
    :target: https://github.com/autoneg/anl/compare/v0.6.2...master

.. |CI| image:: https://github.com/autoneg/anl/workflows/test/badge.svg
    :target: https://www.github.com/autoneg/anl
    :alt: Build Status

.. |PyPiPublished| image:: https://github.com/autoneg/anl/workflows/PyPI/badge.svg
    :target: https://pypi.python.org/pypi/anl
    :alt: Published on Pypi

.. |gitter| image:: https://badges.gitter.im/anl-anac/community.svg
   :alt: Join the chat at https://gitter.im/anl-anac/community
   :target: https://gitter.im/anl-anac/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. |std| image:: https://badges.gitter.im/anl-anac/standard.svg
   :alt: Join the chat at https://gitter.im/anl-anac/standard
   :target: https://gitter.im/anl-anac/standard?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. |collusion| image:: https://badges.gitter.im/anl-anac/collusion.svg
   :alt: Join the chat at https://gitter.im/anl-anac/collusion
   :target: https://gitter.im/anl-anac/collusion?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. |oneshot| image:: https://badges.gitter.im/anl-anac/ones-hot.svg
   :alt: Join the chat at https://gitter.im/anl-anac/one-shot
   :target: https://gitter.im/anl-anac/one-shot?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. |binder| image:: https://mybinder.org/badge_logo.svg
   :alt: run in binder
   :target: https://mybinder.org/v2/gh/autoneg/anl/HEAD

.. end-badges

ANAC Automated Negotiations League Platform

Overview
========

This repository is the official platform for running ANAC Automated Negotiation Leagues (starting 2024). It will contain a package
called `anlXXXX` for the competition run in year XXXX. For example anl2024 will contain all files related to the
2024's version of the competition.


Installation
============

::

    pip install anl

You can also install the in-development version with::

    pip install https://github.com/autoneg/anl/archive/master.zip


Documentation
=============


https://yasserfarouk.github.io/anl/
